@@ -1,5 +1,5 @@
 // 
-// $Id: qaregexp.hpp,v 1.7 1999/08/16 00:49:44 amos Exp $
+// $Id: qaregexp.hpp,v 1.9 2000/06/12 10:54:18 amos Exp $
 //
 // Definition of QaRegExp class
 //
@@ -18,12 +18,15 @@
 class QaRegExp
 {
 public:
-    QaRegExp( const QString &r, bool c = true );
+    QaRegExp( const QString &r, bool c = true, bool newline = true );
     QaRegExp( const QaRegExp &r );
     virtual ~QaRegExp();
 
     bool caseSensitive() const;
+    bool handleNewline() const;
+
     void setCaseSensitive( bool s );
+    void setHandleNewline( bool h );
 
     bool match( const QString &s, int sub = 0 );
     int matchMultiple( const QString &s, int sub = 0 );
@@ -32,7 +35,7 @@ public:
     int matchBeginning( int sub = 0 ) const;
     int matchEnd( int sub = 0 ) const;
     const QaRegExpMatch &matches() const;
-    void split( const QString &s );
+    int split( const QString &s );
     int subCount() const;
     void setExpression( const QString &r );
 
@@ -47,6 +50,7 @@ private:
     QString String;
     int Flags;
     bool Case;
+    bool NewLine;
     bool Subs;
     bool Alloced;
     regex_t RegComp;
